require 'amsi/attribute_parser/boolean'
require 'amsi/attribute_parser/date'
require 'amsi/attribute_parser/date_time'
require 'amsi/attribute_parser/decimal'
require 'amsi/attribute_parser/integer'
require 'amsi/attribute_parser/string'

module Amsi
  # Parse the string value from the XML response into the configured data type
  class AttributeParser
    # @param value [String] the response value from AMSI
    # @param type [Symbol] the attribute's configured data type
    def initialize(value:, type:, timezone: nil)
      @value = value
      @type = type
      @timezone = timezone
    end

    # @return [Object] the parsed attribute value
    def parse
      return unless value

      case type
      when :boolean
        AttributeParser::Boolean.new(value).parse
      when :date
        AttributeParser::Date.new(value).parse
      when :date_time
        AttributeParser::DateTime.new(value, timezone).parse
      when :decimal
        AttributeParser::Decimal.new(value).parse
      when :integer
        AttributeParser::Integer.new(value).parse
      when :string
        AttributeParser::String.new(value).parse
      else
        raise ArgumentError, "Invalid attribute type: #{type}"
      end
    end

    private

    attr_reader :value, :type, :timezone
  end

  private_constant :AttributeParser
end
