require_relative 'base'

module Amsi
  class AttributeParser
    # Parse the response value of a boolean attribute
    class Boolean < Base
      # Values that AMSI responds with for true
      TRUE_VALUES = %w[1 true].freeze
      private_constant :TRUE_VALUES

      # Values that AMSI responds with for true
      FALSE_VALUES = %w[0 false].freeze
      private_constant :FALSE_VALUES

      # @return [true|false] the parsed attribute value
      # @raise [Amsi::Error::InvalidResponse] if the value doesn't parse
      #   into true or false
      def parse
        return true if TRUE_VALUES.include?(value)
        return false if FALSE_VALUES.include?(value)

        raise Error::InvalidResponse, "Invalid boolean response value: #{value}"
      end
    end
  end
end
