require_relative 'base'

module Amsi
  class AttributeParser
    # Parse the response value of a date attribute
    class Date < Base
      # AMSI responds with multiple date formats. This is one format that
      # Date.parse will not parse correctly, so we need special handling
      FORMAT = '%m/%d/%Y'.freeze
      private_constant :FORMAT

      # @return [Date] the parsed attribute value
      def parse
        return if value == ''

        if value =~ %r{/}
          ::Date.strptime(value, FORMAT)
        else
          # AMSI sometimes returns 0001-01-01 for dates, which appears to be
          # their representation of a NULL value.
          date = ::Date.parse(value)
          date.year == 1 ? nil : date
        end
      rescue ArgumentError
        raise Error::InvalidResponse, "Invalid date response value: #{value}"
      end
    end
  end
end
