require 'amsi/validator/request_errors'
require 'amsi/validator/request_fault'
require 'amsi/error/bad_request'

require_relative 'base'

module Amsi
  module DocumentParser
    # Parse the AddGuestCard response
    class GuestCardResult < Base
      private

      # @param body [Hash<String, Object>] the body of the XML response parsed
      #   into a Hash
      # @return [Array<Amsi::Model::Lease>] the leases contained in the
      #   response
      # @raise [Amsi::Error::Base] if the response is invalid
      def parse_body(body)
        response = body['AddGuestCardResponse']
        escaped_result = response['AddGuestCardResult']
        parsed_result = MultiXml.parse(escaped_result)['EDEX']
        Model::GuestCardResult.new(
          contact_seq_no: parsed_result['contactseqno'],
          guest_card_id: parsed_result['guestcardid'],
          property_id: parsed_result['propertyid'],
          status: parsed_result['status']
        )
      end
    end
  end
end
