require 'amsi/validator/request_errors'

require_relative 'base'

module Amsi
  module DocumentParser
    # Parse the GetPropertyResidents response
    class Leases < Base
      private

      # @param body [Hash<String, Object>] the body of the XML response parsed
      #   into a Hash
      # @return [Array<Amsi::Model::Lease>] the leases contained in the
      #   response
      # @raise [Amsi::Error::Base] if the response is invalid
      def parse_body(body)
        lease_hashes(body).map do |lease_hash|
          lease = Model::Lease.new(lease_hash, @params[:timezone])
          lease.occupants = occupant_hashes(lease_hash).map do |occupant_hash|
            Model::Occupant.new(occupant_hash)
          end
          Validator::ResidentEventValidator.new.send_event(lease, @params)
          Validator::ProspectEventValidator.new.send_event(lease, @params)
          lease
        end
      end

      def lease_hashes(body)
        response = body['GetPropertyResidentsResponse']
        escaped_result = response['GetPropertyResidentsResult']
        parsed_result = MultiXml.parse(escaped_result)
        leases = parsed_result['PropertyResidents']['Lease']

        return [] if leases.nil?

        leases.is_a?(Array) ? leases : [leases]
      end

      def occupant_hashes(lease_hash)
        occupants = lease_hash['Occupant']

        return [] if occupants.nil?

        occupants.is_a?(Array) ? occupants : [occupants]
      end
    end
  end
end
