require_relative 'base'

module Amsi
  module Model
    class Lease < Base
      module Status
        CURRENT = 'C'.freeze
        APPLICANT = 'A'.freeze
        INTENT_TO_TRANSFER = 'I'.freeze
        LEASED = 'L'.freeze
        NOTICE = 'N'.freeze
        PREVIOUS = 'P'.freeze
        TRANSFER = 'T'.freeze
        APPROVED = 'V'.freeze
        CANCELLED = 'X'.freeze
      end

      date_attrs(*%i[
                   application_date
                   lease_begin_date
                   lease_end_date
                   lease_sign_date
                   move_in_date
                 ])

      string_attrs(*%i[
                     bldg_id
                     external_reference_id
                     occu_status_code
                     occu_status_code_description
                     property_id
                     resi_id
                     unit_id
                     lease_marketing_source
                     guest_card_no
                   ])

      decimal_attrs :rent_amount

      date_time_attrs :guest_first_contact_date

      alias begin_date lease_begin_date
      alias end_date lease_end_date
      alias sign_date lease_sign_date
      alias lead_id guest_card_no
      alias lead_date guest_first_contact_date
      alias lead_source_code lease_marketing_source
      alias building_id bldg_id
      alias resident_id resi_id
      alias occupant_status_code occu_status_code
      alias occupant_status_code_description occu_status_code_description

      attr_accessor :occupants, :guest_card
      attr_writer :matched_guest_cards

      def matched_guest_cards
        @matched_guest_cards ||= []
      end
    end
  end
end
