require_relative 'base'

require 'amsi/document_parser/guest_card_result'
require 'amsi/request_section/add_guest_card'

module Amsi
  module Request
    # Retrieve resident leases for a given property. Returns current leases only
    #   by default.
    #
    # Required initialization parameters:
    # @property_id [String] AMSI property id
    # @contact_type [String] values in Amsi::Paramter::ContactType
    # @prospect [Amsi::Parameter::Prospect] the prospect to create the guest
    #   card for
    # @see request/base.rb for additional params required by every request.
    class AddGuestCard < Base
      def after_initialize(
        contact_type:, property_id:, prospect:, appointment_date: nil,
        comments: nil,
        contact_datetime: nil,
        date_needed: nil,
        initial_source_id: nil,
        lease_term_desired: nil,
        leasing_agent_id: nil,
        qualified: nil,
        requirements: nil,
        unit_subtype: nil,
        unit_type: nil
      )
        @appointment_date = appointment_date
        @comments = comments
        @contact_datetime = contact_datetime
        @contact_type = contact_type
        @date_needed = date_needed
        @initial_source_id = initial_source_id
        @lease_term_desired = lease_term_desired
        @leasing_agent_id = leasing_agent_id
        @property_id = property_id
        @prospect = prospect
        @qualified = qualified
        @requirements = requirements
        @unit_subtype = unit_subtype
        @unit_type = unit_type
      end

      private

      def sections
        [
          RequestSection::AddGuestCard.new(
            appointment_date: appointment_date,
            comments: comments,
            contact_type: contact_type,
            contact_datetime: contact_datetime,
            date_needed: date_needed,
            initial_source_id: initial_source_id,
            lease_term_desired: lease_term_desired,
            leasing_agent_id: leasing_agent_id,
            property_id: property_id,
            prospect: prospect,
            qualified: qualified,
            requirements: requirements,
            unit_subtype: unit_subtype,
            unit_type: unit_type
          )
        ]
      end

      def parser
        DocumentParser::GuestCardResult.new
      end

      attr_reader :appointment_date,
                  :comments,
                  :contact_datetime,
                  :contact_type,
                  :date_needed,
                  :initial_source_id,
                  :lease_term_desired,
                  :leasing_agent_id,
                  :property_id,
                  :prospect,
                  :qualified,
                  :requirements,
                  :unit_subtype,
                  :unit_type
    end
  end
end
