require_relative 'base'

require 'amsi/request_section/property_resident_filter'
require 'amsi/document_parser/leases'

module Amsi
  module Request
    # Retrieve resident leases for a given property. Returns current leases only
    # by default.
    #
    # Custom required initialization parameters:
    # @property_id [String] AMSI property id
    # @lease_status [String] Lease status filter.
    # @include_marketing_source [Boolean] flag to include marketing sources
    # @params [Hash] extra configuration fields
    #   Valid values in: Amsi::Model::Lease::Status
    # @see request/base.rb for additional params required by every request.
    class GetPropertyResidents < Base
      def after_initialize(property_id:, lease_status:, params:, include_marketing_source: false)
        @property_id = property_id
        @lease_status = lease_status
        @include_marketing_source = include_marketing_source
        @params = params
      end

      private

      def parser
        DocumentParser::Leases.new(@params)
      end

      def sections
        [
          RequestSection::PropertyResidentFilter.new(
            property_id: property_id,
            lease_status: lease_status,
            include_marketing_source: include_marketing_source
          )
        ]
      end

      attr_reader :property_id, :lease_status, :include_marketing_source, :params
    end
  end
end
