module Amsi
  module RequestSection
    # Generate the property list filter elements of an AMSI request
    class PropertyListFilter
      def initialize(
        include_leasing_agents: false,
        include_marketing_sources: false,
        include_unit_types: false,
        property_id: nil
      )
        @include_leasing_agents = include_leasing_agents
        @include_marketing_sources = include_marketing_sources
        @include_unit_types = include_unit_types
        @property_id = property_id
      end

      def generate(xml_builder)
        xml_builder.XMLData do |xml_data|
          xml_data.cdata edex.to_s
        end
      end

      private

      def edex
        Nokogiri::XML::Builder.new do |xml_builder|
          xml_builder.EDEX do |edex|
            edex.propertyid(property_id)
            edex.includeamenities('0')
            edex.includeclasses('0')
            edex.includeincomecodes('0')
            edex.includeleasingagents(include_leasing_agents ? '1' : '0')
            edex.includemarketingsources(include_marketing_sources ? '1' : '0')
            edex.includeunittypes(include_unit_types ? '1' : '0')
          end
        end.doc.root
      end

      attr_reader :include_leasing_agents,
                  :include_marketing_sources,
                  :include_unit_types,
                  :property_id
    end
  end
end
