module Amsi
  module RequestSection
    # Generate the property resident filter elements of an AMSI request
    class PropertyResidentFilter
      def initialize(property_id:, lease_status:, include_marketing_source: false)
        @property_id = property_id
        @lease_status = lease_status
        @include_marketing_source = include_marketing_source
      end

      def generate(xml_builder)
        xml_builder.XMLData do |xml_data|
          xml_data.cdata edex.to_s
        end
      end

      private

      def edex
        Nokogiri::XML::Builder.new do |xml_builder|
          xml_builder.EDEX do |edex|
            edex.propertyid property_id
            edex.leasestatus lease_status
            edex.includemarketingsource include_marketing_source ? '1' : '0'
          end
        end.doc.root
      end

      attr_reader :property_id, :lease_status, :include_marketing_source
    end
  end
end
