require 'faraday'

module Amsi
  module Utils
    # Send a SOAP request to AMSI
    class RequestFetcher
      module Status
        TIMEOUT = 504
      end

      # @param generator [RequestGenerator] an instance of a RequestGenerator
      def initialize(generator:, conn: Faraday.new)
        @generator = generator
        @conn = conn
      end

      # @return [String] the XML response from AMSI
      def fetch
        response = conn.post(generator.url) do |request|
          request.body = generator.body
          request.headers = generator.headers
        end

        if response.status == Status::TIMEOUT
          raise Error::RequestTimeout,
                'The server did not respond in a reasonable timeframe'
        end

        response.body
      end

      private

      attr_reader :generator, :conn
    end
  end
end
