require 'nokogiri'

module Amsi
  module Utils
    # Generate a SOAP request for a specific action and sections
    class RequestGenerator
      ENVELOPE_ATTRIBUTES = {
        'xmlns:soap' => 'http://schemas.xmlsoap.org/soap/envelope/'
      }.freeze

      ACTION_ATTRIBUTES = {
        'xmlns' => 'http://tempuri.org/'
      }.freeze

      # @param url: [String] the URL to POST to
      # @param soap_action: [String] the PascalCase action to request from AMSI.
      # @param sections: [Array<RequestSection>] the setion generators that will
      #   be used to generate the body of the XML request
      def initialize(url:, soap_action:, sections:)
        @url = url
        @soap_action = soap_action
        @sections = sections
      end

      def headers
        {
          'Content-Type' => 'text/xml; charset=utf-8',
          'SOAPAction' => "http://tempuri.org/#{soap_action}"
        }
      end

      # @return [String] the XML request for the specified action and sections
      def body
        Nokogiri::XML::Builder.new do |xml_builder|
          xml_builder['soap'].Envelope(ENVELOPE_ATTRIBUTES) do
            xml_builder['soap'].Body do
              xml_builder.send(soap_action, ACTION_ATTRIBUTES) do
                sections.each do |section|
                  section.generate(xml_builder)
                end
              end
            end
          end
        end.to_xml
      end

      attr_reader :url

      private

      attr_reader :soap_action, :sections
    end
  end
end
